@@ -1,3 +1,6 @@
+from typing import Dict
+
+
 def get_single_field_from_type_uri(field_type: str):
     if field_type.startswith('https://wegenenverkeer.data.vlaanderen.be/ns/') and '#' in field_type:
         return field_type.split('#')[1]
@@ -32,20 +35,18 @@ def get_single_field_from_type_uri(field_type: str):
         raise NotImplemented('not supported field_type in get_single_field_from_type_uri()')
 
 
-def get_non_single_field_from_type_uri(field_type: str):
+def get_non_single_field_from_type_uri(field_type: str, valid_uri_and_types: Dict):
     if '#Dtc' in field_type:
         type_name = field_type[field_type.find("#") + 1::]
         return ['ComplexField', type_name]
-    if field_type.startswith("https://schema.org/"):
-        if field_type == "https://schema.org/ContactPoint":
-            return ['ComplexField', "DtcContactinfo"]
-        if field_type == "https://schema.org/OpeningHoursSpecification":
-            return ['ComplexField', "DtcOpeningsurenSpecificatie"]
-        raise NotImplementedError(f"Field of type {field_type} is not implemented in DatatypeCreator")
+    if field_type in valid_uri_and_types.keys():
+        return ['ComplexField', valid_uri_and_types[field_type]]
     if '#Dte' in field_type or '#KwantWrd' in field_type:
         type_name = field_type[field_type.find("#") + 1::]
         return ['ComplexField', type_name]
-    if '#Kl' in field_type:
+    if '#Kl' in field_type or field_type in [
+            'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#AntiParkeerpaalType',
+            'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KLLuidsprekerVormgeving']:
         type_name = field_type[field_type.find("#") + 1::]
         return ['KeuzelijstField', type_name]
     if '#Dtu' in field_type:
@@ -55,12 +56,12 @@ def get_non_single_field_from_type_uri(field_type: str):
     raise NotImplementedError(f'not supported field_type {field_type} in get_non_single_field_from_type_uri()')
 
 
-def get_field_name_from_type_uri(attribuut_type):
+def get_field_name_from_type_uri(attribuut_type, valid_uri_and_types):
     if attribuut_type.startswith('http://www.w3.org/2001/XMLSchema#'):
         return get_single_field_from_type_uri(attribuut_type)
     if attribuut_type.startswith("https://schema.org/"):
-        return get_non_single_field_from_type_uri(attribuut_type)[1]
-    return get_non_single_field_from_type_uri(attribuut_type)[1]
+        return get_non_single_field_from_type_uri(attribuut_type, valid_uri_and_types)[1]
+    return get_non_single_field_from_type_uri(attribuut_type, valid_uri_and_types)[1]
 
 
 def get_attributen_by_type_field(oslo_collector, type_field, oslo_datatype):
@@ -72,17 +73,11 @@ def get_attributen_by_type_field(oslo_collector, type_field, oslo_datatype):
         return oslo_collector.find_primitive_datatype_attributes_by_class_uri(oslo_datatype.objectUri)
 
 
-def get_type_name_of_complex_attribuut(type_uri: str):
-    if type_uri.startswith("https://wegenenverkeer.data.vlaanderen.be/ns/") or type_uri.startswith(
-            "http://www.w3.org/2001/XMLSchema#"):
-        return type_uri[type_uri.find("#") + 1::]
-    elif type_uri.startswith("https://schema.org/"):
-        if type_uri == "https://schema.org/ContactPoint":
-            return "DtcContactinfo"
-        if type_uri == "https://schema.org/OpeningHoursSpecification":
-            return "DtcOpeningsurenSpecificatie"
-        raise NotImplementedError(
-            f"Field of type {type_uri} is not implemented in DatatypeCreator.get_type_name_of_complex_attribuut")
+def get_type_name_of_complex_attribuut(type_uri: str, valid_uri_and_types):
+    if '/ns/' in type_uri or type_uri.startswith('http://www.w3.org/2001/XMLSchema#'):
+        return type_uri[type_uri.find('#') + 1::]
+    if type_uri in valid_uri_and_types.keys():
+        return valid_uri_and_types[type_uri]
 
     raise NotImplementedError(f"get_type_name_of_complex_attribuut fails to get typename from {type_uri}")
 
@@ -93,7 +88,7 @@ def get_type_link_from_attribuut(oslo_collector, attribuut):
         return type_link
 
 
-def get_fields_and_names_from_list_of_attributes(attributen):
+def get_fields_and_names_from_list_of_attributes(attributen, valid_uri_and_types):
     if len(attributen) == 0:
         return []
 
@@ -106,7 +101,7 @@ def get_fields_and_names_from_list_of_attributes(attributen):
         map(lambda a: (get_single_field_from_type_uri(a.type), a.name), primitive_types_list))
 
     for nonPrimitiveType in other_types_list:
-        select_types_list.append((get_field_name_from_type_uri(nonPrimitiveType.type), nonPrimitiveType.name))
+        select_types_list.append((get_field_name_from_type_uri(nonPrimitiveType.type, valid_uri_and_types), nonPrimitiveType.name))
 
     distinct_types_list = list(set(select_types_list))
     sorted_list = sorted(distinct_types_list, key=lambda t: t)
@@ -114,7 +109,7 @@ def get_fields_and_names_from_list_of_attributes(attributen):
 
 
 def get_type_name_of_union_attribuut(type_uri: str):
-    if type_uri.startswith("https://wegenenverkeer.data.vlaanderen.be/ns/"):
-        return type_uri[type_uri.find("#") + 1::]
+    if '/ns/' in type_uri and '#' in type_uri:
+        return type_uri[type_uri.find('#') + 1::]
 
-    raise NotImplementedError(f"get_type_name_of_complex_attribuut fails to get typename from {type_uri}")
+    raise NotImplementedError(f'get_type_name_of_complex_attribuut fails to get typename from {type_uri}')
