@@ -1,3 +1,4 @@
+from pathlib import Path
 from typing import Type, Union
 
 from otlmow_modelbuilder.GeometrieInMemoryCreator import GeometrieInMemoryCreator
@@ -5,12 +6,14 @@ from otlmow_modelbuilder.GeometrieType import GeometrieType
 
 
 class GeometrieArtefactCollector:
-    def __init__(self, geometrie_in_memory_creator: GeometrieInMemoryCreator):
-        self.geometrie_in_memory_creator = geometrie_in_memory_creator
-        self.geometrie_types = [GeometrieType]
+    def __init__(self, path: Path):
+        self.path = path
 
-    def collect(self):
-        self.geometrie_types = self.geometrie_in_memory_creator.get_all_geometrie_types()
+        self.geometrie_types: [GeometrieType] = None
+
+    def collect_all(self):
+        with GeometrieInMemoryCreator(self.path) as memory_creator:
+            self.geometrie_types = memory_creator.get_all_geometrie_types()
 
     def find_by_objectUri(self, objectUri: str) -> Union[Type[GeometrieType], None]:
         result = list(filter(lambda g: g.objectUri == objectUri, self.geometrie_types))
