@@ -1,11 +1,8 @@
 from pathlib import Path
 
 from otlmow_modelbuilder.GeometrieArtefactCollector import GeometrieArtefactCollector
-from otlmow_modelbuilder.GeometrieInMemoryCreator import GeometrieInMemoryCreator
-from otlmow_modelbuilder.OSLOInMemoryCreator import OSLOInMemoryCreator
+from otlmow_modelbuilder.OSLOCollector import OSLOCollector
 from otlmow_modelbuilder.OTLModelCreator import OTLModelCreator
-from otlmow_modelbuilder.SQLDataClasses.OSLOCollector import OSLOCollector
-from otlmow_modelbuilder.SQLDbReader import SQLDbReader
 from otlmow_modelbuilder.SettingsManager import load_settings
 
 
@@ -20,18 +17,15 @@ class ModelBuilder:
             this_file_path = Path(__file__)
             directory = this_file_path.parent
 
-        sql_reader = SQLDbReader(otl_subset_location)
-        oslo_creator = OSLOInMemoryCreator(sql_reader)
-        subset_collector = OSLOCollector(oslo_creator)
+        subset_collector = OSLOCollector(otl_subset_location)
+        subset_collector.collect_all()
+
         geo_artefact_collector = None
         if geometry_artefact_location is not None:
-            sql_reader_ga = SQLDbReader(geometry_artefact_location)
-            geo_memory_creator = GeometrieInMemoryCreator(sql_reader_ga)
-            geo_artefact_collector = GeometrieArtefactCollector(geo_memory_creator)
+            geo_artefact_collector = GeometrieArtefactCollector(geometry_artefact_location)
 
-        subset_collector.collect()
         if geo_artefact_collector is not None:
-            geo_artefact_collector.collect()
+            geo_artefact_collector.collect_all()
 
         settings = load_settings(settings_path)
 
