@@ -11,7 +11,7 @@ from otlmow_modelbuilder.HelperFunctions import get_ns_and_name_from_uri, get_cl
 from otlmow_modelbuilder.AbstractDatatypeCreator import AbstractDatatypeCreator
 from otlmow_modelbuilder.SQLDataClasses.Inheritance import Inheritance
 from otlmow_modelbuilder.SQLDataClasses.OSLOClass import OSLOClass
-from otlmow_modelbuilder.SQLDataClasses.OSLOCollector import OSLOCollector
+from otlmow_modelbuilder.OSLOCollector import OSLOCollector
 
 
 class OTLClassCreator(AbstractDatatypeCreator):
@@ -28,7 +28,8 @@ class OTLClassCreator(AbstractDatatypeCreator):
                                                 inheritances=self.oslo_collector.inheritances)
             self.geometry_types = gip.process_inheritances()
 
-    def create_blocks_to_write_from_classes(self, oslo_class: OSLOClass, model_location='', valid_uri_and_types: Dict = None) -> [str]:
+    def create_blocks_to_write_from_classes(self, oslo_class: OSLOClass, model_location='',
+                                            valid_uri_and_types: Dict = None) -> [str]:
         if not isinstance(oslo_class, OSLOClass):
             raise ValueError(f"Input is not a OSLOClass")
 
@@ -45,16 +46,16 @@ class OTLClassCreator(AbstractDatatypeCreator):
 
         return self.create_block_from_class(oslo_class, model_location, valid_uri_and_types=valid_uri_and_types)
 
-    def create_block_from_class(self, oslo_class: OSLOClass, model_location: str = '', valid_uri_and_types: Dict = None) -> [str]:
+    def create_block_from_class(self, oslo_class: OSLOClass, model_location: str = '',
+                                valid_uri_and_types: Dict = None) -> [str]:
         if valid_uri_and_types is None:
             valid_uri_and_types = {}
         attributen = self.oslo_collector.find_attributes_by_class(oslo_class)
         inheritances = self.oslo_collector.find_inheritances_by_class(oslo_class)
         list_of_geometry_types = self.get_geometry_types_from_uri(oslo_class.objectUri)
 
-        if oslo_class.objectUri in ['https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject',
-                                    'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#Derdenobject',
-                                    'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AbstracteAanvullendeGeometrie']:
+        if oslo_class.objectUri in {'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject',
+                                    'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#Derdenobject'}:
             inheritances.append(
                 Inheritance(base_name='OTLAsset', base_uri='', class_name='', class_uri='', deprecated_version=''))
             inheritances.append(
@@ -68,7 +69,10 @@ class OTLClassCreator(AbstractDatatypeCreator):
             inheritances.append(
                 Inheritance(base_name='OTLObject', base_uri='', class_name='', class_uri='', deprecated_version=''))
 
-        elif oslo_class.objectUri == 'http://purl.org/dc/terms/Agent':
+        elif oslo_class.objectUri in {
+                'http://purl.org/dc/terms/Agent',
+                'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#Toegangsprocedure',
+                'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AbstracteAanvullendeGeometrie'}:
             inheritances.append(
                 Inheritance(base_name='OTLObject', base_uri='', class_name='', class_uri='', deprecated_version=''))
             inheritances.append(
@@ -77,7 +81,7 @@ class OTLClassCreator(AbstractDatatypeCreator):
 
         datablock = ['# coding=utf-8']
         if len(attributen) > 0:
-            datablock.append('from otlmow_model.BaseClasses.OTLAttribuut import OTLAttribuut')
+            datablock.append('from otlmow_model.OtlmowModel.BaseClasses.OTLObject import OTLAttribuut')
 
         if oslo_class.abstract == 1:
             if len(inheritances) + len(list_of_geometry_types) < 1:
@@ -89,7 +93,7 @@ class OTLClassCreator(AbstractDatatypeCreator):
             for inheritance in inheritances:
                 if inheritance.base_name in ['OTLAsset', 'OTLObject', 'RelationInteractor', 'DavieRelatieAttributes']:
                     datablock.append(
-                        f'from otlmow_model.BaseClasses.{inheritance.base_name} import {inheritance.base_name}')
+                        f'from otlmow_model.OtlmowModel.BaseClasses.{inheritance.base_name} import {inheritance.base_name}')
                 else:
                     class_directory = 'Classes'
                     ns = None
@@ -98,14 +102,7 @@ class OTLClassCreator(AbstractDatatypeCreator):
                     if ns is not None:
                         class_directory = get_class_directory_from_ns(ns).replace('/', '.')
 
-                    model_module = 'otlmow_model'
-                    if model_location != '':
-                        if 'UnitTests' in model_location:
-                            model_module = 'UnitTests'
-                        modules_index = model_location.rfind('/' + model_module)
-                        modules = model_location[modules_index + 1:]
-                        model_module = modules.replace('/', '.')
-                    datablock.append(f'from {model_module}.{class_directory}.{inheritance.base_name} '
+                    datablock.append(f'from ...{class_directory}.{inheritance.base_name} '
                                      f'import {inheritance.base_name}')
 
         if any(atr.readonly == 1 for atr in attributen):
@@ -118,23 +115,19 @@ class OTLClassCreator(AbstractDatatypeCreator):
                        'IntegerField', 'KeuzelijstField', 'UnionTypeField', 'URIField', 'LiteralField',
                        'NonNegIntegerField', 'TimeField', 'StringField', 'UnionWaarden']
         for type_field in list_of_fields:
-            model_module = 'otlmow_model'
-            if model_location != '' and type_field not in base_fields:
-                if 'UnitTests' in model_location:
-                    model_module = 'UnitTests'
-                modules_index = model_location.rfind('/' + model_module)
-                modules = model_location[modules_index + 1:]
-                model_module = modules.replace('/', '.')
             if type_field not in base_fields:
-                datablock.append(f'from {model_module}.Datatypes.{type_field} import {type_field}')
+                if oslo_class.objectUri == 'http://purl.org/dc/terms/Agent':
+                    datablock.append(f'from ..Datatypes.{type_field} import {type_field}')
+                else:
+                    datablock.append(f'from ...Datatypes.{type_field} import {type_field}')
             else:
-                datablock.append(f'from {model_module}.BaseClasses.{type_field} import {type_field}')
+                datablock.append(f'from otlmow_model.OtlmowModel.BaseClasses.{type_field} import {type_field}')
 
         if 'Bevestiging' in oslo_class.objectUri:
             pass
 
         for geometry_type in list_of_geometry_types:
-            datablock.append(f'from otlmow_model.GeometrieTypes.{geometry_type} import {geometry_type}')
+            datablock.append(f'from otlmow_model.OtlmowModel.GeometrieTypes.{geometry_type} import {geometry_type}')
 
         datablock.append('')
         datablock.append('')
@@ -157,15 +150,8 @@ class OTLClassCreator(AbstractDatatypeCreator):
         if oslo_class.abstract == 1:
             datablock.append('    @abstractmethod')
         datablock.append('    def __init__(self):')
-        if len(inheritances) + len(list_of_geometry_types) == 1:
-            datablock.append('        super().__init__()')
-            datablock.append('')
-        elif len(inheritances) + len(list_of_geometry_types) > 1:
-            for inheritance in inheritances:
-                datablock.append(f'        {inheritance.base_name}.__init__(self)')
-            for geo_type in sorted(list_of_geometry_types):
-                datablock.append(f'        {geo_type}.__init__(self)')
-            datablock.append('')
+        datablock.append('        super().__init__()')
+        datablock.append('')
 
         self.add_relations_to_datablock(datablock, oslo_class.objectUri)
 
@@ -229,10 +215,12 @@ class OTLClassCreator(AbstractDatatypeCreator):
                 f"        self.add_valid_relation(relation='{relation.objectUri}', target='{relation.doel_uri}'{deprecated})")
         datablock.append('')
 
-    relation_interactor_uris = ['https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AbstracteAanvullendeGeometrie',
-                                'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject',
-                                'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#Derdenobject',
-                                'http://purl.org/dc/terms/Agent']
+    relation_interactor_uris = {
+        'https://wegenenverkeer.data.vlaanderen.be/ns/abstracten#AbstracteAanvullendeGeometrie',
+        'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#AIMObject',
+        'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#Derdenobject',
+        'https://wegenenverkeer.data.vlaanderen.be/ns/implementatieelement#Toegangsprocedure',
+        'http://purl.org/dc/terms/Agent'}
 
     def search_recursive_inheritance_for_relation_interactor(self, base_uri: str) -> bool:
         inheritances = self.oslo_collector.find_inheritances_by_class_uri(base_uri)
@@ -244,19 +232,19 @@ class OTLClassCreator(AbstractDatatypeCreator):
         return False
 
     def sort_inheritances_for_relation_interactor_priority(self, inheritances):
-        first_good_candidate = None
-
-        for inheritance in inheritances:
-            if inheritance.base_uri in self.relation_interactor_uris:
-                first_good_candidate = inheritance
-                break
-            if self.search_recursive_inheritance_for_relation_interactor(inheritance.base_uri):
-                first_good_candidate = inheritance
-                break
-
-        if first_good_candidate is None:
-            return inheritances
-
-        inheritances.remove(first_good_candidate)
-        inheritances.insert(0, first_good_candidate)
+        # first_good_candidate = None
+        #
+        # for inheritance in inheritances:
+        #     if inheritance.base_uri in self.relation_interactor_uris:
+        #         first_good_candidate = inheritance
+        #         break
+        #     if self.search_recursive_inheritance_for_relation_interactor(inheritance.base_uri):
+        #         first_good_candidate = inheritance
+        #         break
+        #
+        # if first_good_candidate is None:
+        #     return inheritances
+        #
+        # inheritances.remove(first_good_candidate)
+        # inheritances.insert(0, first_good_candidate)
         return inheritances
